﻿using HelloPrismForWinRT.Models;
using Microsoft.Practices.Prism.StoreApps.Interfaces;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace HelloPrismForWinRT.Services
{
    public class OrderRepository : IOrderRepository
    {
        readonly ObservableCollection<OrderItem> _OrderItems = new ObservableCollection<OrderItem>();
        private readonly ISessionStateService _StateService;
        private const string CurrentOrderKey = "CurrentOrderKey";
        public OrderRepository(ISessionStateService stateService)
        {
            _StateService = stateService;
            if (_StateService.SessionState.ContainsKey(CurrentOrderKey))
            {
                IEnumerable<OrderItem> sessionItems = _StateService.SessionState[CurrentOrderKey] as IEnumerable<OrderItem>;
                if (sessionItems != null)
                {
                    foreach (OrderItem item in sessionItems)
                    {
                        _OrderItems.Add(item);
                    }
                }
            }
            
        }

        public void AddToOrder(Product product, int quantity)
        {
            var orderitem = (from oi in _OrderItems where oi.Product.ProductId == product.ProductId select oi).FirstOrDefault();
            if (orderitem == null)
                _OrderItems.Add(new OrderItem { Product = product, Quantity = quantity });
            else orderitem.Quantity += quantity;
            // Write the collection out to the state service
            _StateService.SessionState[CurrentOrderKey] = _OrderItems.ToArray();
        }

        public ObservableCollection<OrderItem> CurrentOrderItems { get { return _OrderItems; } }
    }
}
