﻿using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Practices.Prism.StoreApps;
using Microsoft.Practices.Prism.StoreApps.Interfaces;
using Windows.UI.Xaml.Navigation;
using HelloPrismForWinRT.Services;
using HelloPrismForWinRT.Models;
using System.Collections.ObjectModel;

namespace HelloPrismForWinRT.ViewModels
{
    public class AddSalePageViewModel : ViewModel
    {
        private readonly INavigationService _NavService;
        private readonly IProductsRepository _ProductsRespository;
        private readonly IOrderRepository _OrderRepository;
        //private Product _SelectedProduct;
        private int _SelectedProductId;
        private int _Quantity = 1;

        public AddSalePageViewModel(INavigationService navService, 
            IProductsRepository productsRespository, 
            IOrderRepository orderRepository)
        {
            _OrderRepository = orderRepository;
            _ProductsRespository = productsRespository;
            _NavService = navService;
            GoBackCommand = new DelegateCommand(
                () => _NavService.GoBack(),
                () => _NavService.CanGoBack());
            AddToOrderCommand = new DelegateCommand(OnAddToOrder, CanAddToOrder);
        }

        public DelegateCommand GoBackCommand { get; private set; }
        public DelegateCommand AddToOrderCommand { get; private set; }

        public override void OnNavigatedTo(object navigationParameter,
            NavigationMode navigationMode, Dictionary<string, object> viewState)
        {
            base.OnNavigatedTo(navigationParameter, navigationMode, viewState);
        }

        public IEnumerable<Product> Products
        {
            get { return _ProductsRespository.AllProducts(); }
        }

        public ObservableCollection<OrderItem> CurrentOrderItems
        {
            get { return _OrderRepository.CurrentOrderItems; }
        }

        //[RestorableState]
        //public Product SelectedProduct
        //{
        //    get { return _SelectedProduct; }
        //    set 
        //    { 
        //        SetProperty(ref _SelectedProduct, value); 
        //        AddToOrderCommand.RaiseCanExecuteChanged(); 
        //    }
        //}

        [RestorableState]
        public int SelectedProductId
        {
            get { return _SelectedProductId; }
            set 
            { 
                SetProperty(ref _SelectedProductId, value);
                AddToOrderCommand.RaiseCanExecuteChanged();
            }
        }

        [RestorableState]
        public int Quantity
        {
            get { return _Quantity; }
            set { SetProperty(ref _Quantity, value); }
        }

        private bool CanAddToOrder()
        {
            var prod = (from p in _ProductsRespository.AllProducts() where p.ProductId == _SelectedProductId select p).FirstOrDefault();
            return prod != null;
        }

        private void OnAddToOrder()
        {
            var prod = (from p in _ProductsRespository.AllProducts() where p.ProductId == _SelectedProductId select p).FirstOrDefault();
            _OrderRepository.AddToOrder(prod, Quantity);
        }

    }
}
