// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY OF
// ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
// Copyright (c) Microsoft Corporation. All rights reserved


using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;

namespace Microsoft.Practices.Prism.StoreApps.Interfaces
{
    /// <summary>
    /// The IValidatableBindableBase interface was created to add validation support for model classes that contains validation rules.
    /// The default implementation of IValidatableBindableBase is the ValidatableBindableBase class, which contains the logic to run the validation rules of the
    /// instance of a model class and return the results of this validation as a list of properties' errors.
    /// </summary>
    public interface IValidatableBindableBase : INotifyPropertyChanged
    {
        /// <summary>
        /// Gets or sets a value indicating whether this instance is validation enabled.
        /// </summary>
        /// <value>
        /// <c>true</c> if validation is enabled for this instance; otherwise, <c>false</c>.
        /// </value>
        bool IsValidationEnabled { get; set; }

        /// <summary>
        /// Return the BindableValidator instance, which have an indexer property that returns.
        /// </summary>
        /// <value>
        /// The Bindable Validator Indexer property.
        /// </value>
        BindableValidator Errors { get; }

        /// <summary>
        /// Occurs when the Errors collection changed because of new errors were added or old errors were fixed.
        /// </summary>
        event EventHandler<DataErrorsChangedEventArgs> ErrorsChanged;

        /// <summary>
        /// Gets all errors.
        /// </summary>
        /// <returns> A ReadOnlyDictionary which key is a property name and the value is a ReadOnlyCollection of the error strings.</returns>
        ReadOnlyDictionary<string, ReadOnlyCollection<string>> GetAllErrors();

        /// <summary>
        /// Validates the properties of the current instance.
        /// </summary>
        /// <returns>Returns <c>true</c> if all properties pass the validation rules; otherwise, false.</returns>
        bool ValidateProperties();

        /// <summary>
        /// Sets the error collection of this instance.
        /// </summary>
        /// <param name="entityErrors">The entity errors.</param>
        void SetAllErrors(IDictionary<string, ReadOnlyCollection<string>> entityErrors);
    }
}